Credits
=======

Contributors
------------

* Lei Xu <leonard.xu.thu@gmail.com>
* Kalyan Veeramachaneni <kalyan@csail.mit.edu>
* Manuel Alvarez <manuel@pythiac.com>
* Carles Sala <csala@csail.mit.edu>
